@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING, Iterable, Hashable, Union, SupportsInt, Mapping, Any
+from typing import TYPE_CHECKING, Iterable, Hashable, Literal, Union, SupportsInt, Mapping, Any, overload
 from pathlib import Path
 import numpy as np
 from numpy.typing import DTypeLike
@@ -27,7 +27,7 @@ SupportSlicing = Union[
     Mapping[str, SupportOneSlicing],
 ]
 
-class MetaArray(AxesMixin, np.ndarray[Any, np.dtype[np.number]]):
+class MetaArray(AxesMixin, np.ndarray):
     additional_props = ["_source", "_metadata", "_name"]
     NP_DISPATCH = {}
     _name: str
@@ -119,7 +119,7 @@ class MetaArray(AxesMixin, np.ndarray[Any, np.dtype[np.number]]):
         return self.axes.tuple(super().shape)
     
     def __getitem__(self, key: SupportSlicing) -> Self:
-        key = slicer.solve_slicer(key, self.axes)
+        key = slicer.solve_slicer(key, self.axes, self.shape)
 
         if isinstance(key, np.ndarray):
             key = self._broadcast(key)
@@ -133,7 +133,7 @@ class MetaArray(AxesMixin, np.ndarray[Any, np.dtype[np.number]]):
         return out
     
     def __setitem__(self, key: SupportSlicing, value):
-        key = slicer.solve_slicer(key, self.axes)
+        key = slicer.solve_slicer(key, self.axes, self.shape)
         
         if isinstance(key, MetaArray) and key.dtype == bool:
             key = axesop.add_axes(self.axes, self.shape, key, key.axes)
@@ -181,7 +181,7 @@ class MetaArray(AxesMixin, np.ndarray[Any, np.dtype[np.number]]):
         if indexer is not None:
             kwargs.update(indexer)
 
-        key = slicer.solve_slicer(kwargs, self.axes)
+        key = slicer.solve_slicer(kwargs, self.axes, self.shape)
         out = super().__getitem__(key)  # get item as np.ndarray
         
         if isinstance(out, self.__class__):  # cannot set attribution to such as numpy.int32 
@@ -527,10 +527,32 @@ class MetaArray(AxesMixin, np.ndarray[Any, np.dtype[np.number]]):
         out._set_info(self, new_axes=new_axes)
         return out
     
+    @overload
+    def min(
+        self,
+        axis: Literal[None] = None,
+        out: Any | None = None,
+        keepdims: Literal[False] = False,
+        *,
+        where: Any = _NoValue,
+    ) -> np.number:
+        ...
+    
+    @overload
+    def min(
+        self,
+        axis: int | AxisLike | Iterable[int] | Iterable[AxisLike],
+        out: Any | None = None,
+        keepdims: bool = False,
+        *,
+        where: Any = _NoValue,
+    ) -> Self:
+        ...
+
     def min(
         self,
         axis=None,
-        out: None = None,
+        out: Any | None = None,
         keepdims: bool = False,
         *,
         where: np.ndarray = _NoValue,
@@ -538,10 +560,32 @@ class MetaArray(AxesMixin, np.ndarray[Any, np.dtype[np.number]]):
         """Minimum value of the array along a given axis."""
         return np.min(self, axis=axis, out=out, keepdims=keepdims, where=where)
     
+    @overload
+    def max(
+        self,
+        axis: Literal[None] = None,
+        out: Any | None = None,
+        keepdims: Literal[False] = False,
+        *,
+        where: Any = _NoValue,
+    ) -> np.number:
+        ...
+    
+    @overload
+    def max(
+        self,
+        axis: int | AxisLike | Iterable[int] | Iterable[AxisLike],
+        out: Any | None = None,
+        keepdims: bool = False,
+        *,
+        where: Any = _NoValue,
+    ) -> Self:
+        ...
+
     def max(
         self,
         axis=None,
-        out: None = None,
+        out: Any | None = None,
         keepdims: bool = False,
         *,
         where: np.ndarray = _NoValue,
@@ -549,11 +593,36 @@ class MetaArray(AxesMixin, np.ndarray[Any, np.dtype[np.number]]):
         """Maximum value of the array along a given axis."""
         return np.max(self, axis=axis, out=out, keepdims=keepdims, where=where)
     
+    
+    @overload
+    def mean(
+        self,
+        axis: Literal[None] = None,
+        dtype: DTypeLike | None = None,
+        out: Any = None,
+        keepdims: Literal[False] = False,
+        *,
+        where: Any = _NoValue,
+    ) -> np.number:
+        ...
+    
+    @overload
+    def mean(
+        self,
+        axis: int | AxisLike | Iterable[int] | Iterable[AxisLike],
+        dtype: DTypeLike | None = None,
+        out: Any = None,
+        keepdims: bool = False,
+        *,
+        where: Any = _NoValue,
+    ) -> Self:
+        ...
+
     def mean(
         self,
         axis=None,
-        dtype: DTypeLike = None,
-        out: None = None,
+        dtype: DTypeLike | None = None,
+        out: Any | None = None,
         keepdims: bool = False,
         *,
         where: np.ndarray = _NoValue,
@@ -561,11 +630,35 @@ class MetaArray(AxesMixin, np.ndarray[Any, np.dtype[np.number]]):
         """Mean value of the array along a given axis."""
         return np.mean(self, axis=axis, dtype=dtype, out=out, keepdims=keepdims, where=where)
     
+    @overload
+    def sum(
+        self,
+        axis: Literal[None] = None,
+        dtype: DTypeLike | None = None,
+        out: Any | None = None,
+        keepdims: Literal[False] = False,
+        *,
+        where: Any = _NoValue,
+    ) -> np.number:
+        ...
+    
+    @overload
+    def sum(
+        self,
+        axis: int | AxisLike | Iterable[int] | Iterable[AxisLike],
+        dtype: DTypeLike | None = None,
+        out: Any | None = None,
+        keepdims: bool = False,
+        *,
+        where: Any = _NoValue,
+    ) -> Self:
+        ...
+
     def sum(
         self,
         axis=None,
         dtype: DTypeLike = None,
-        out: None = None,
+        out: Any | None = None,
         keepdims: bool = False,
         *,
         where: np.ndarray = _NoValue,
@@ -573,6 +666,30 @@ class MetaArray(AxesMixin, np.ndarray[Any, np.dtype[np.number]]):
         """Sum value of the array along a given axis."""
         return np.sum(self, axis=axis, dtype=dtype, out=out, keepdims=keepdims, where=where)
     
+    @overload
+    def std(
+        self,
+        axis: Literal[None] = None,
+        dtype: DTypeLike | None = None,
+        out: Any | None = None,
+        keepdims: Literal[False] = False,
+        *,
+        where: Any = _NoValue,
+    ) -> np.number:
+        ...
+    
+    @overload
+    def std(
+        self,
+        axis: int | AxisLike | Iterable[int] | Iterable[AxisLike],
+        dtype: DTypeLike | None = None,
+        out: Any | None = None,
+        keepdims: bool = False,
+        *,
+        where: Any = _NoValue,
+    ) -> Self:
+        ...
+
     def std(
         self,
         axis=None,
